SchedulePass

Struct SchedulePass 

pub struct SchedulePass;
An optimization pass that computes and logs the schedule for debugging.

This pass does NOT modify the module. It only computes and logs schedules for all entry points when the RUST_LOG level includes debug messages. It can also be used to attach schedule metadata.